import click
from os import getenv
from pathlib import Path
from functools import update_wrapper

FULL_PATH = fr"{getenv('USERPROFILE')}\bridgecli.cfg"

def check_browser(func):
    '''
        Documentação necessária: https://click.palletsprojects.com/en/7.x/commands/#decorating-commands
    '''
    @click.pass_context
    def wrapper(ctx, *args,**kwargs):
        hasbrowser, browser = exists_bridgecli()
        if not hasbrowser:
            raise Exception('Use `bgd set browser` para configurar o navegador de sua preferencia.')
        return ctx.invoke(func, browser, *args, **kwargs)            
    return update_wrapper(wrapper, func)

def exists_bridgecli() -> bool:
    """
        Valida se existe o arquivo bridgecli.cfg foi configurado.
    """
    if Path(FULL_PATH).is_file():
        try:
            with open(FULL_PATH, 'r') as _file:
                file = _file.readlines()
                values = file[0].split('=')
                hasbrowser = True if values[0] == 'BROWSER' and len(values) > 1 else False
                user_browser = values[1]
                return hasbrowser, user_browser
        except:
            raise Exception('Erro no conteúdo do arquivo.')
    else:
        raise FileNotFoundError